# py3lsd
opencv4.1及以上版本取消了lsd算法，之前的工程需要用到lsd又想用最新版本的opencv4.1及以上的功能，这个项目可以完美替代lsd；
# 特别说明
## time： 2020-05-01
1. 作者在pip上不进行更新，导致每次都要手动修复，无法在工程中使用,所以自己上传一版优化好的；不喜勿喷；
2. [特别鸣谢：原代码](https://github.com/primetang/pylsd)
